==> guikachu-1.5.6.tar.gz: guikachu-1.5.6/src/io/rcp/parser.h <==
/* A Bison parser, made by GNU Bison 2.0.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     ID_TOKEN = 258,
     AUTOID = 259,
     BEG = 260,
     END = 261,
     LBRACE = 262,
     RBRACE = 263,
     HELPID = 264,
     MENUID = 265,
     DEFAULTBTNID = 266,
     APPLICATIONICONNAME = 267,
     ALERT = 268,
     MENU = 269,
     STRING = 270,
     STRINGTABLE = 271,
     BITMAP = 272,
     BITMAPFAMILY = 273,
     DIALOG_CONFIRMATION = 274,
     DIALOG_INFORMATION = 275,
     DIALOG_WARNING = 276,
     DIALOG_ERROR = 277,
     BUTTON = 278,
     POPUPTRIGGER = 279,
     REPEATBUTTON = 280,
     CHECKBOX = 281,
     SELECTORTRIGGER = 282,
     LABEL = 283,
     PUSHBUTTON = 284,
     GRAFFITISTATEINDICATOR = 285,
     FIELD = 286,
     LIST = 287,
     FORMBITMAP = 288,
     GADGET = 289,
     POPUPLIST = 290,
     TABLE = 291,
     SCROLLBAR = 292,
     SLIDER = 293,
     AUTO = 294,
     USABLE = 295,
     NONUSABLE = 296,
     DISABLED = 297,
     LEFTANCHOR = 298,
     RIGHTANCHOR = 299,
     FRAME = 300,
     NOFRAME = 301,
     BOLDFRAME = 302,
     LEFTALIGN = 303,
     RIGHTALIGN = 304,
     NUMERIC = 305,
     AUTOSHIFT = 306,
     HASSCROLLBAR = 307,
     VERTICAL = 308,
     FEEDBACK = 309,
     VISIBLEITEMS = 310,
     SEARCH = 311,
     ROWS = 312,
     COLUMNS = 313,
     COLUMNWIDTHS = 314,
     VALUE = 315,
     MIN_VAL = 316,
     MAX_VAL = 317,
     PAGESIZE = 318,
     GRAPHICAL = 319,
     BITMAPID = 320,
     SELECTEDBITMAPID = 321,
     THUMBID = 322,
     BACKGROUNDID = 323,
     BITMAPGREY = 324,
     BITMAPGREY16 = 325,
     BITMAPCOLOR16 = 326,
     BITMAPCOLOR = 327,
     BITMAPCOLOR16K = 328,
     BITMAPFAMILYSPECIAL = 329,
     BITMAPFAMILYEX = 330,
     COMPRESS = 331,
     NOCOMPRESS = 332,
     FORCECOMPRESS = 333,
     COLORTABLE = 334,
     NOCOLORTABLE = 335,
     TRANSPARENT = 336,
     TRANSPARENTINDEX = 337,
     DENSITY = 338,
     BPP = 339,
     AT = 340,
     BUTTONS = 341,
     CHECKED = 342,
     DEFAULTBUTTON = 343,
     DYNAMICSIZE = 344,
     EDITABLE = 345,
     FONT = 346,
     FORM = 347,
     GROUP = 348,
     MAXCHARS = 349,
     MENUITEM = 350,
     MESSAGE = 351,
     MODAL = 352,
     MULTIPLELINES = 353,
     NONEDITABLE = 354,
     NOSAVEBEHIND = 355,
     PULLDOWN = 356,
     SAVEBEHIND = 357,
     SEPARATOR = 358,
     SINGLELINE = 359,
     TITLE = 360,
     UNDERLINED = 361,
     VERSION_TOKEN = 362,
     CENTER = 363,
     PREVLEFT = 364,
     PREVRIGHT = 365,
     PREVTOP = 366,
     PREVBOTTOM = 367,
     PREVWIDTH = 368,
     PREVHEIGHT = 369,
     QUOTESTRING = 370,
     WORD = 371,
     PLUS = 372,
     MINUS = 373,
     TIMES = 374,
     DIV = 375,
     NUMBER = 376
   };
#endif
#define ID_TOKEN 258
#define AUTOID 259
#define BEG 260
#define END 261
#define LBRACE 262
#define RBRACE 263
#define HELPID 264
#define MENUID 265
#define DEFAULTBTNID 266
#define APPLICATIONICONNAME 267
#define ALERT 268
#define MENU 269
#define STRING 270
#define STRINGTABLE 271
#define BITMAP 272
#define BITMAPFAMILY 273
#define DIALOG_CONFIRMATION 274
#define DIALOG_INFORMATION 275
#define DIALOG_WARNING 276
#define DIALOG_ERROR 277
#define BUTTON 278
#define POPUPTRIGGER 279
#define REPEATBUTTON 280
#define CHECKBOX 281
#define SELECTORTRIGGER 282
#define LABEL 283
#define PUSHBUTTON 284
#define GRAFFITISTATEINDICATOR 285
#define FIELD 286
#define LIST 287
#define FORMBITMAP 288
#define GADGET 289
#define POPUPLIST 290
#define TABLE 291
#define SCROLLBAR 292
#define SLIDER 293
#define AUTO 294
#define USABLE 295
#define NONUSABLE 296
#define DISABLED 297
#define LEFTANCHOR 298
#define RIGHTANCHOR 299
#define FRAME 300
#define NOFRAME 301
#define BOLDFRAME 302
#define LEFTALIGN 303
#define RIGHTALIGN 304
#define NUMERIC 305
#define AUTOSHIFT 306
#define HASSCROLLBAR 307
#define VERTICAL 308
#define FEEDBACK 309
#define VISIBLEITEMS 310
#define SEARCH 311
#define ROWS 312
#define COLUMNS 313
#define COLUMNWIDTHS 314
#define VALUE 315
#define MIN_VAL 316
#define MAX_VAL 317
#define PAGESIZE 318
#define GRAPHICAL 319
#define BITMAPID 320
#define SELECTEDBITMAPID 321
#define THUMBID 322
#define BACKGROUNDID 323
#define BITMAPGREY 324
#define BITMAPGREY16 325
#define BITMAPCOLOR16 326
#define BITMAPCOLOR 327
#define BITMAPCOLOR16K 328
#define BITMAPFAMILYSPECIAL 329
#define BITMAPFAMILYEX 330
#define COMPRESS 331
#define NOCOMPRESS 332
#define FORCECOMPRESS 333
#define COLORTABLE 334
#define NOCOLORTABLE 335
#define TRANSPARENT 336
#define TRANSPARENTINDEX 337
#define DENSITY 338
#define BPP 339
#define AT 340
#define BUTTONS 341
#define CHECKED 342
#define DEFAULTBUTTON 343
#define DYNAMICSIZE 344
#define EDITABLE 345
#define FONT 346
#define FORM 347
#define GROUP 348
#define MAXCHARS 349
#define MENUITEM 350
#define MESSAGE 351
#define MODAL 352
#define MULTIPLELINES 353
#define NONEDITABLE 354
#define NOSAVEBEHIND 355
#define PULLDOWN 356
#define SAVEBEHIND 357
#define SEPARATOR 358
#define SINGLELINE 359
#define TITLE 360
#define UNDERLINED 361
#define VERSION_TOKEN 362
#define CENTER 363
#define PREVLEFT 364
#define PREVRIGHT 365
#define PREVTOP 366
#define PREVBOTTOM 367
#define PREVWIDTH 368
#define PREVHEIGHT 369
#define QUOTESTRING 370
#define WORD 371
#define PLUS 372
#define MINUS 373
#define TIMES 374
#define DIV 375
#define NUMBER 376




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 332 "parser.yy"
typedef union YYSTYPE {
    char *str;
    int   num;
} YYSTYPE;
/* Line 1318 of yacc.c.  */
#line 284 "y.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;

==> guikachu-1.5.7.tar.gz: guikachu-1.5.7/src/io/rcp/parser.h <==
/* A Bison parser, made by GNU Bison 2.1.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     ID_TOKEN = 258,
     AUTOID = 259,
     BEG = 260,
     END = 261,
     LBRACE = 262,
     RBRACE = 263,
     HELPID = 264,
     MENUID = 265,
     DEFAULTBTNID = 266,
     APPLICATIONICONNAME = 267,
     ALERT = 268,
     MENU = 269,
     STRING = 270,
     STRINGTABLE = 271,
     BITMAP = 272,
     BITMAPFAMILY = 273,
     DIALOG_CONFIRMATION = 274,
     DIALOG_INFORMATION = 275,
     DIALOG_WARNING = 276,
     DIALOG_ERROR = 277,
     BUTTON = 278,
     POPUPTRIGGER = 279,
     REPEATBUTTON = 280,
     CHECKBOX = 281,
     SELECTORTRIGGER = 282,
     LABEL = 283,
     PUSHBUTTON = 284,
     GRAFFITISTATEINDICATOR = 285,
     FIELD = 286,
     LIST = 287,
     FORMBITMAP = 288,
     GADGET = 289,
     POPUPLIST = 290,
     TABLE = 291,
     SCROLLBAR = 292,
     SLIDER = 293,
     AUTO = 294,
     USABLE = 295,
     NONUSABLE = 296,
     DISABLED = 297,
     LEFTANCHOR = 298,
     RIGHTANCHOR = 299,
     FRAME = 300,
     NOFRAME = 301,
     BOLDFRAME = 302,
     LEFTALIGN = 303,
     RIGHTALIGN = 304,
     NUMERIC = 305,
     AUTOSHIFT = 306,
     HASSCROLLBAR = 307,
     VERTICAL = 308,
     FEEDBACK = 309,
     VISIBLEITEMS = 310,
     SEARCH = 311,
     ROWS = 312,
     COLUMNS = 313,
     COLUMNWIDTHS = 314,
     VALUE = 315,
     MIN_VAL = 316,
     MAX_VAL = 317,
     PAGESIZE = 318,
     GRAPHICAL = 319,
     BITMAPID = 320,
     SELECTEDBITMAPID = 321,
     THUMBID = 322,
     BACKGROUNDID = 323,
     BITMAPGREY = 324,
     BITMAPGREY16 = 325,
     BITMAPCOLOR16 = 326,
     BITMAPCOLOR = 327,
     BITMAPCOLOR16K = 328,
     BITMAPFAMILYSPECIAL = 329,
     BITMAPFAMILYEX = 330,
     COMPRESS = 331,
     NOCOMPRESS = 332,
     FORCECOMPRESS = 333,
     COLORTABLE = 334,
     NOCOLORTABLE = 335,
     TRANSPARENT = 336,
     TRANSPARENTINDEX = 337,
     DENSITY = 338,
     BPP = 339,
     AT = 340,
     BUTTONS = 341,
     CHECKED = 342,
     DEFAULTBUTTON = 343,
     DYNAMICSIZE = 344,
     EDITABLE = 345,
     FONT = 346,
     FORM = 347,
     GROUP = 348,
     MAXCHARS = 349,
     MENUITEM = 350,
     MESSAGE = 351,
     MODAL = 352,
     MULTIPLELINES = 353,
     NONEDITABLE = 354,
     NOSAVEBEHIND = 355,
     PULLDOWN = 356,
     SAVEBEHIND = 357,
     SEPARATOR = 358,
     SINGLELINE = 359,
     TITLE = 360,
     UNDERLINED = 361,
     VERSION_TOKEN = 362,
     CENTER = 363,
     PREVLEFT = 364,
     PREVRIGHT = 365,
     PREVTOP = 366,
     PREVBOTTOM = 367,
     PREVWIDTH = 368,
     PREVHEIGHT = 369,
     QUOTESTRING = 370,
     WORD = 371,
     PLUS = 372,
     MINUS = 373,
     TIMES = 374,
     DIV = 375,
     NUMBER = 376
   };
#endif
/* Tokens.  */
#define ID_TOKEN 258
#define AUTOID 259
#define BEG 260
#define END 261
#define LBRACE 262
#define RBRACE 263
#define HELPID 264
#define MENUID 265
#define DEFAULTBTNID 266
#define APPLICATIONICONNAME 267
#define ALERT 268
#define MENU 269
#define STRING 270
#define STRINGTABLE 271
#define BITMAP 272
#define BITMAPFAMILY 273
#define DIALOG_CONFIRMATION 274
#define DIALOG_INFORMATION 275
#define DIALOG_WARNING 276
#define DIALOG_ERROR 277
#define BUTTON 278
#define POPUPTRIGGER 279
#define REPEATBUTTON 280
#define CHECKBOX 281
#define SELECTORTRIGGER 282
#define LABEL 283
#define PUSHBUTTON 284
#define GRAFFITISTATEINDICATOR 285
#define FIELD 286
#define LIST 287
#define FORMBITMAP 288
#define GADGET 289
#define POPUPLIST 290
#define TABLE 291
#define SCROLLBAR 292
#define SLIDER 293
#define AUTO 294
#define USABLE 295
#define NONUSABLE 296
#define DISABLED 297
#define LEFTANCHOR 298
#define RIGHTANCHOR 299
#define FRAME 300
#define NOFRAME 301
#define BOLDFRAME 302
#define LEFTALIGN 303
#define RIGHTALIGN 304
#define NUMERIC 305
#define AUTOSHIFT 306
#define HASSCROLLBAR 307
#define VERTICAL 308
#define FEEDBACK 309
#define VISIBLEITEMS 310
#define SEARCH 311
#define ROWS 312
#define COLUMNS 313
#define COLUMNWIDTHS 314
#define VALUE 315
#define MIN_VAL 316
#define MAX_VAL 317
#define PAGESIZE 318
#define GRAPHICAL 319
#define BITMAPID 320
#define SELECTEDBITMAPID 321
#define THUMBID 322
#define BACKGROUNDID 323
#define BITMAPGREY 324
#define BITMAPGREY16 325
#define BITMAPCOLOR16 326
#define BITMAPCOLOR 327
#define BITMAPCOLOR16K 328
#define BITMAPFAMILYSPECIAL 329
#define BITMAPFAMILYEX 330
#define COMPRESS 331
#define NOCOMPRESS 332
#define FORCECOMPRESS 333
#define COLORTABLE 334
#define NOCOLORTABLE 335
#define TRANSPARENT 336
#define TRANSPARENTINDEX 337
#define DENSITY 338
#define BPP 339
#define AT 340
#define BUTTONS 341
#define CHECKED 342
#define DEFAULTBUTTON 343
#define DYNAMICSIZE 344
#define EDITABLE 345
#define FONT 346
#define FORM 347
#define GROUP 348
#define MAXCHARS 349
#define MENUITEM 350
#define MESSAGE 351
#define MODAL 352
#define MULTIPLELINES 353
#define NONEDITABLE 354
#define NOSAVEBEHIND 355
#define PULLDOWN 356
#define SAVEBEHIND 357
#define SEPARATOR 358
#define SINGLELINE 359
#define TITLE 360
#define UNDERLINED 361
#define VERSION_TOKEN 362
#define CENTER 363
#define PREVLEFT 364
#define PREVRIGHT 365
#define PREVTOP 366
#define PREVBOTTOM 367
#define PREVWIDTH 368
#define PREVHEIGHT 369
#define QUOTESTRING 370
#define WORD 371
#define PLUS 372
#define MINUS 373
#define TIMES 374
#define DIV 375
#define NUMBER 376




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 332 "parser.yy"
typedef union YYSTYPE {
    char *str;
    int   num;
} YYSTYPE;
/* Line 1447 of yacc.c.  */
#line 285 "y.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;
